
Changelog
=========

0.0.1 (2020-06-24)
------------------

* First release on PyPI with cookiecutter HelloWorld template to set everything up.

0.0.2 (2020-06-29)
------------------

* Still cookiecutter code but addition of docstrings to test sphinx apidoc capabilities.
